<?php

namespace FiloBlu\Rma\Model\Rma\Status;

use FiloBlu\Rma\Model\RmaEmailManagment;
use Magento\Framework\Api\AttributeValueFactory;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Magento\Rma\Api\RmaAttributesManagementInterface;
use Magento\Rma\Api\RmaRepositoryInterface;
use Magento\Sales\Model\Order\Address\Renderer as AddressRenderer;
use Magento\Rma\Model\Rma;

/**
 * Class History
 * @package Model\Rma\Status
 *
 */
class History extends \Magento\Rma\Model\Rma\Status\History
{
    /**
     * @var string
     */
    const XML_PATH_RECEIVED_EMAIL = 'sales_email/magento_rma_received';

    /**
     * @var RmaEmailManagment
     */
    protected $rmaEmailManagment;


    /**
     * History constructor.
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Api\ExtensionAttributesFactory $extensionFactory
     * @param AttributeValueFactory $customAttributeFactory
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Rma\Model\RmaFactory $rmaFactory
     * @param \Magento\Rma\Model\Config $rmaConfig
     * @param \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder
     * @param \Magento\Framework\Stdlib\DateTime\DateTime $dateTimeDateTime
     * @param \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation
     * @param \Magento\Rma\Helper\Data $rmaHelper
     * @param TimezoneInterface $localeDate
     * @param RmaRepositoryInterface $rmaRepositoryInterface
     * @param RmaAttributesManagementInterface $metadataService
     * @param AddressRenderer $addressRenderer
     * @param RmaEmailManagment $rmaEmailManagment
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource|null $resource
     * @param \Magento\Framework\Data\Collection\AbstractDb|null $resourceCollection
     * @param array $data
     */
    public function __construct(\Magento\Framework\Model\Context $context,
                                \Magento\Framework\Registry $registry,
                                \Magento\Framework\Api\ExtensionAttributesFactory $extensionFactory,
                                AttributeValueFactory $customAttributeFactory,
                                \Magento\Store\Model\StoreManagerInterface $storeManager,
                                \Magento\Rma\Model\RmaFactory $rmaFactory,
                                \Magento\Rma\Model\Config $rmaConfig,
                                \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder,
                                \Magento\Framework\Stdlib\DateTime\DateTime $dateTimeDateTime,
                                \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation,
                                \Magento\Rma\Helper\Data $rmaHelper,
                                TimezoneInterface $localeDate,
                                RmaRepositoryInterface $rmaRepositoryInterface,
                                RmaAttributesManagementInterface $metadataService,
                                AddressRenderer $addressRenderer,
                                RmaEmailManagment $rmaEmailManagment,
                                \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
                                \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
                                array $data = [])
    {
        $this->rmaEmailManagment = $rmaEmailManagment;
        parent::__construct($context, $registry, $extensionFactory, $customAttributeFactory, $storeManager, $rmaFactory, $rmaConfig, $transportBuilder, $dateTimeDateTime, $inlineTranslation, $rmaHelper, $localeDate, $rmaRepositoryInterface, $metadataService, $addressRenderer, $resource, $resourceCollection, $data);
    }


    /**
     * @return History|\Magento\Rma\Model\Rma\Status\History
     */
    public function sendReceivedEmail()
    {
        try{
          return $this->_sendRmaEmailWithItems($this->getRma(), $this->getRootReceivedRmaEmail());
        }catch (\Exception $e){
            $this->_logger->critical($e->getMessage());
        }
    }

    /**
     * @param $config
     * @return History|\Magento\Rma\Model\Rma\Status\History
     */
    public function sendRmaEmail($config)
    {
        try{
            return $this->_sendRmaEmailWithItems($this->getRma(), $config);
        }catch (\Exception $e){
            $this->_logger->critical($e->getMessage());
        }

    }

    /**
     * @return string
     */
    public function getRootReceivedRmaEmail()
    {
        return self::XML_PATH_RECEIVED_EMAIL;
    }

    /**
     * @return History|\Magento\Rma\Model\Rma\Status\History
     */
    public function sendAuthorizeEmail()
    {
        $rma = $this->getRma();
        return $this->rmaEmailManagment->checkIfSendRmaEmail($rma);
    }

    /**
     * Sending email with RMA data
     *
     * @return $this
     */
    public function sendNewRmaEmail()
    {
        return $this;
    }


}